.. _spkg_webencodings:

webencodings: Character encoding aliases for legacy web content
===============================================================

Description
-----------

Character encoding aliases for legacy web content.

License
-------

BSD License


Upstream Contact
----------------

Home Page: https://github.com/gsnedders/python-webencodings

Dependencies
------------

Python


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    0.5.1

version_requirements.txt::

    webencodings >=0.5.1

See https://repology.org/project/python:webencodings/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install webencodings\>=0.5.1

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i webencodings

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-webencodings

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install webencodings

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-webencodings

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-webencodings

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/webencodings

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-webencodings

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-webencodings

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-webencodings

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-webencodings


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
